@@ -1,11 +1,9 @@
 package CF3;
 use strict;
 
-use Package::Transporter sub{eval shift};
-BEGIN {
-	Package::Transporter->new()
-	->array_indices('ATB_', [], qw(NAME  TYPE  STOCK  PRICE));
-}
+use Package::Transporter sub{eval shift}, sub {
+	$_[0]->array_indices('ATB_', [], qw(NAME  TYPE  STOCK  PRICE));
+};
 
 #...
 sub sell {
@@ -15,4 +13,4 @@ sub sell {
 	my $costs = $amount * $self->[ATB_PRICH];
 
 	return($costs);
-}
\ No newline at end of file
+}
